{"": "", "Manage system services": "\uc2dc\uc2a4\ud15c \uc11c\ube44\uc2a4 \uad00\ub9ac", "Service": "\uc11c\ube44\uc2a4", "Filter services": "\uc11c\ube44\uc2a4 \ud544\ud130", "Manager": "\uad00\ub9ac\uc790", "Done": "\uc644\ub8cc", "Services": "\uc11c\ube44\uc2a4", "Service operation failed": "\uc11c\ube44\uc2a4 \uc791\uc5c5 \uc2e4\ud328"}